@@ -129,7 +129,11 @@ class dyn_vec:
         self.parent = parent
         self.name = name+"_vector"
 
-        self.filepath = bpsci.__file__.replace("__init__.py", "")+'\\assets\\objects\\arrow.obj'
+        self.filepath = __file__.replace("__init__.py", "").replace("\\core.py", "")+'\\assets\\objects\\arrow.obj'
 
         vec = bpy.ops.import_scene.obj(filepath=self.filepath)
-        vec.parent = self.parent
\ No newline at end of file
+        vec = bpy.context.selected_objects[0]
+        vec.parent = self.parent
+	vec.name = self.name
+
+
